<?php
/**
 * Module Name: Firewall
 * Module Description: Protect your site with Jetpack's Web Application Firewall
 * Sort Order: 5
 * First Introduced: 10.9
 * Requires Connection: Yes
 * Auto Activate: No
 * Module Tags: Firewall, WAF
 * Feature: Security
 *
 * @package automattic/jetpack
 */
